@@ -1,4 +1,3 @@
-// [[Rcpp::plugins(cpp11)]]
 #include <Rcpp.h>
 using namespace Rcpp;
 
@@ -192,7 +191,7 @@ Vector<RTYPE> flagleadCppImpl(const Vector<RTYPE>& x, const IntegerVector& n, co
       }
     }
   }
-  DUPLICATE_ATTRIB(out, x);
+  SHALLOW_DUPLICATE_ATTRIB(out, x);
   if(ns != 1) {
     Rf_setAttrib(out, R_NamesSymbol, R_NilValue);
     Rf_dimgets(out, Dimension(l, ns));
@@ -452,7 +451,7 @@ Matrix<RTYPE> flagleadmCppImpl(const Matrix<RTYPE>& x, const IntegerVector& n, c
       }
     }
   }
-  DUPLICATE_ATTRIB(out, x);
+  SHALLOW_DUPLICATE_ATTRIB(out, x);
   if(ns != 1) Rf_dimgets(out, Dimension(l, col*ns));
   if(names) {
     Rf_dimnamesgets(out, List::create(rownames(x), colnam)); // colnames(out) = colnam deletes row names !
@@ -537,7 +536,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
               int i = 0;
               while(i != np) outjp[i++] = ff;
               for( ; i != row; ++i) outjp[i] = column[i - np];
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               NumericVector outjp = no_init_vector(row);
@@ -545,7 +544,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
               int i = row, st = row+np;
               while(i != st) outjp[--i] = ff;
               for( ; i--; ) outjp[i] = column[i - np];
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -569,7 +568,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
               int i = 0;
               while(i != np) outjp[i++] = ff;
               for( ; i != row; ++i) outjp[i] = column[i - np];
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else if(np<0) {
@@ -578,7 +577,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
               int i = row, st = row+np;
               while(i != st) outjp[--i] = ff;
               for( ; i--; ) outjp[i] = column[i - np];
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else {
@@ -603,7 +602,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
               int i = 0;
               while(i != np) outjp[i++] = ff;
               for( ; i != row; ++i) outjp[i] = column[i - np];
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               CharacterVector outjp = no_init_vector(row);
@@ -611,7 +610,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
               int i = row, st = row+np;
               while(i != st) outjp[--i] = ff;
               for( ; i--; ) outjp[i] = column[i - np];
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -662,7 +661,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               NumericVector outjp = no_init_vector(os);
@@ -674,7 +673,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -702,7 +701,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else if(np<0) {
@@ -715,7 +714,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else {
@@ -744,7 +743,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               CharacterVector outjp = no_init_vector(os);
@@ -756,7 +755,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -796,7 +795,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   ++seen[g[i]];
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               NumericVector outjp = no_init_vector(gss);
@@ -810,7 +809,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   --seen[g[i]];
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -840,7 +839,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   ++seen[g[i]];
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else if(np<0) {
@@ -855,7 +854,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   --seen[g[i]];
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else {
@@ -886,7 +885,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   ++seen[g[i]];
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               CharacterVector outjp = no_init_vector(gss);
@@ -900,7 +899,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   --seen[g[i]];
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -969,7 +968,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               NumericVector outjp = no_init_vector(gss);
@@ -981,7 +980,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -1009,7 +1008,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else if(np<0) {
@@ -1022,7 +1021,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               if(txj == LGLSXP) SET_TYPEOF(outjp, LGLSXP);
               out[pos] = outjp;
             } else {
@@ -1051,7 +1050,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else if(np<0) {
               CharacterVector outjp = no_init_vector(gss);
@@ -1063,7 +1062,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
                   outjp[i] = ff;
                 }
               }
-              DUPLICATE_ATTRIB(outjp, column);
+              SHALLOW_DUPLICATE_ATTRIB(outjp, column);
               out[pos] = outjp;
             } else {
               if(names) nam[pos] = na[j];
@@ -1078,7 +1077,7 @@ List flagleadlCpp(const List& x, const IntegerVector& n = 1, const SEXP& fill =
       }
     }
   }
-  DUPLICATE_ATTRIB(out, x);
+  SHALLOW_DUPLICATE_ATTRIB(out, x);
   if(names) { // best way to code this ??
     Rf_namesgets(out, nam);
   } else {
