@@ -40,7 +40,7 @@ void fsum_double_g_impl(double *restrict pout, const double *restrict px, const
       else pout[pg[i]] += px[i];
     }
   } else {
-    memset(pout, 0.0, sizeof(double) * ng);
+    memset(pout, 0, sizeof(double) * ng);
     --pout;
     if(narm == 2) {
       for(int i = 0; i != l; ++i) if(NISNAN(px[i])) pout[pg[i]] += px[i];
@@ -80,7 +80,7 @@ double fsum_double_omp_impl(const double *restrict px, const int narm, const int
 //       }
 //     }
 //   } else {
-//     memset(pout, 0.0, sizeof(double) * ng);
+//     memset(pout, 0, sizeof(double) * ng);
 //     #pragma omp parallel for num_threads(nthreads) reduction(+:pout[:ng]) // shared(pout)
 //     for(int i = 0; i < l; ++i) {
 //       // #pragma omp atomic
@@ -120,7 +120,7 @@ void fsum_weights_g_impl(double *restrict pout, const double *restrict px, const
       else pout[pg[i]] += px[i] * pw[i];
     }
   } else {
-    memset(pout, 0.0, sizeof(double) * ng);
+    memset(pout, 0, sizeof(double) * ng);
     --pout;
     if(narm == 2) {
       for(int i = l; i--; ) if(NISNAN(px[i]) && NISNAN(pw[i])) pout[pg[i]] += px[i] * pw[i];
@@ -161,7 +161,7 @@ double fsum_weights_omp_impl(const double *restrict px, const double *restrict p
 //       else pout[pg[i]-1] += px[i] * pw[i];
 //     }
 //   } else {
-//     memset(pout, 0.0, sizeof(double) * ng);
+//     memset(pout, 0, sizeof(double) * ng);
 //     #pragma omp parallel for num_threads(nthreads) reduction(+:pout[:ng])
 //     for(int i = 0; i < l; ++i) pout[pg[i]-1] += px[i] * pw[i]; // Used to stop loop when all groups passed with NA, but probably no speed gain since groups are mostly ordered.
 //   }
@@ -566,6 +566,19 @@ SEXP fsum_g_impl(SEXP x, const int ng, const int *pg, int narm) {
   return res;
 }
 
+void fsum_g_omp_impl(SEXP x, void *pres, const int ng, const int *pg, int narm) {
+  switch(TYPEOF(x)) {
+    case REALSXP:
+      fsum_double_g_impl(pres, REAL(x), ng, pg, narm, length(x));
+      break;
+    case LGLSXP:
+    case INTSXP:
+      fsum_int_g_impl(pres, INTEGER(x), ng, pg, narm, length(x));
+      break;
+    default: error("Unsupported SEXP type: '%s'", type2char(TYPEOF(x)));
+  }
+}
+
 SEXP fsum_wg_impl(SEXP x, const int ng, const int *pg, double *pw, int narm) {
   int l = length(x), nprotect = 1;
   if(l < 1) return ScalarReal(NA_REAL);
@@ -584,6 +597,8 @@ SEXP fsum_wg_impl(SEXP x, const int ng, const int *pg, double *pw, int narm) {
 }
 
 
+
+
 #undef COLWISE_FSUM_LIST
 #define COLWISE_FSUM_LIST(FUN, WFUN)                           \
 if(nwl) {                                                      \
@@ -647,16 +662,32 @@ SEXP fsumlC(SEXP x, SEXP Rng, SEXP g, SEXP w, SEXP Rnarm, SEXP fill, SEXP Rdrop,
     if(nthreads > l) nthreads = l;
     if(nwl) { // no weights
       if(nthreads > 1 && l > 1) {
+        for(int j = 0; j != l; ++j) {
+          SEXP xj = px[j], outj;
+          SET_VECTOR_ELT(out, j, outj = allocVector(TYPEOF(px[j]) == REALSXP ? REALSXP : INTSXP, ng));
+          if(ATTRIB(xj) != R_NilValue && !(isObject(xj) && inherits(xj, "ts"))) copyMostAttrib(xj, outj);
+        }
         #pragma omp parallel for num_threads(nthreads)
-        for(int j = 0; j < l; ++j) pout[j] = fsum_g_impl(px[j], ng, pg, narm);
+        for(int j = 0; j < l; ++j) fsum_g_omp_impl(px[j], DATAPTR(pout[j]), ng, pg, narm);
       } else {
         for(int j = 0; j != l; ++j) pout[j] = fsum_g_impl(px[j], ng, pg, narm);
       }
     } else {
       double *restrict pw = REAL(w);
       if(nthreads > 1 && l > 1) {
+        int nrx = length(g);
+        for(int j = 0, dup = 0; j != l; ++j) {
+          SEXP xj = px[j], outj;
+          SET_VECTOR_ELT(out, j, outj = allocVector(REALSXP, ng));
+          if(ATTRIB(xj) != R_NilValue && !(isObject(xj) && inherits(xj, "ts"))) copyMostAttrib(xj, outj);
+          if(TYPEOF(xj) != REALSXP) {
+            if(TYPEOF(xj) != INTSXP && TYPEOF(xj) != LGLSXP) error("Unsupported SEXP type: '%s'", type2char(TYPEOF(xj)));
+            if(dup == 0) {x = PROTECT(shallow_duplicate(x)); ++nprotect; px = SEXPPTR(x); dup = 1;}
+            SET_VECTOR_ELT(x, j, coerceVector(xj, REALSXP));
+          }
+        }
         #pragma omp parallel for num_threads(nthreads)
-        for(int j = 0; j < l; ++j) pout[j] = fsum_wg_impl(px[j], ng, pg, pw, narm);
+        for(int j = 0; j < l; ++j) fsum_weights_g_impl(REAL(pout[j]), REAL(px[j]), ng, pg, pw, narm, nrx);
       } else {
         for(int j = 0; j != l; ++j) pout[j] = fsum_wg_impl(px[j], ng, pg, pw, narm);
       }
