@@ -35,12 +35,6 @@ wmean <- function(x, w, na.rm = FALSE) {
   bsum(x*w)/bsum(w)
 }
 
-wBY <- function(x, f, FUN, w, ...) {
-  if(is.atomic(x) && !is.array(x)) return(mapply(FUN, split(x, f), split(w, f), ...))
-  wspl <- split(w, f)
-  if(is.atomic(x)) return(dapply(x, function(xi) mapply(FUN, split(xi, f), wspl, ...)))
-  qDF(dapply(x, function(xi) mapply(FUN, split(xi, f), wspl, ...), return = "matrix"))
-}
 
 for (nth in 1:2) {
 
@@ -178,18 +172,18 @@ test_that("fmean with weights performs like wmean (defined above)", {
   expect_equal(fmean(mtcars, w = wdat, na.rm = FALSE), dapply(mtcars, wmean, wdat))
   expect_equal(fmean(mtcNA, w = wdat, na.rm = FALSE), dapply(mtcNA, wmean, wdat))
   expect_equal(fmean(mtcNA, w = wdat), dapply(mtcNA, wmean, wdat, na.rm = TRUE))
-  expect_equal(fmean(x, f, w), wBY(x, f, wmean, w))
-  expect_equal(fmean(x, f, w, na.rm = FALSE), wBY(x, f, wmean, w))
-  expect_equal(fmean(xNA, f, w, na.rm = FALSE), wBY(xNA, f, wmean, w))
-  expect_equal(fmean(xNA, f, w), wBY(xNA, f, wmean, w, na.rm = TRUE))
-  expect_equal(fmean(m, g, wdat), wBY(m, gf, wmean, wdat))
-  expect_equal(fmean(m, g, wdat, na.rm = FALSE), wBY(m, gf, wmean, wdat))
-  expect_equal(fmean(mNA, g, wdat, na.rm = FALSE),  wBY(mNA, gf, wmean, wdat))
-  expect_equal(fmean(mNA, g, wdat), wBY(mNA, gf, wmean, wdat, na.rm = TRUE))
-  expect_equal(fmean(mtcars, g, wdat), wBY(mtcars, gf, wmean, wdat))
-  expect_equal(fmean(mtcars, g, wdat, na.rm = FALSE), wBY(mtcars, gf, wmean, wdat))
-  expect_equal(fmean(mtcNA, g, wdat, na.rm = FALSE), wBY(mtcNA, gf, wmean, wdat))
-  expect_equal(fmean(mtcNA, g, wdat), wBY(mtcNA, gf, wmean, wdat, na.rm = TRUE))
+  expect_equal(fmean(x, f, w), BY(x, f, wmean, w))
+  expect_equal(fmean(x, f, w, na.rm = FALSE), BY(x, f, wmean, w))
+  expect_equal(fmean(xNA, f, w, na.rm = FALSE), BY(xNA, f, wmean, w))
+  expect_equal(fmean(xNA, f, w), BY(xNA, f, wmean, w, na.rm = TRUE))
+  expect_equal(fmean(m, g, wdat), BY(m, gf, wmean, wdat))
+  expect_equal(fmean(m, g, wdat, na.rm = FALSE), BY(m, gf, wmean, wdat))
+  expect_equal(fmean(mNA, g, wdat, na.rm = FALSE),  BY(mNA, gf, wmean, wdat))
+  expect_equal(fmean(mNA, g, wdat), BY(mNA, gf, wmean, wdat, na.rm = TRUE))
+  expect_equal(fmean(mtcars, g, wdat), BY(mtcars, gf, wmean, wdat))
+  expect_equal(fmean(mtcars, g, wdat, na.rm = FALSE), BY(mtcars, gf, wmean, wdat))
+  expect_equal(fmean(mtcNA, g, wdat, na.rm = FALSE), BY(mtcNA, gf, wmean, wdat))
+  expect_equal(fmean(mtcNA, g, wdat), BY(mtcNA, gf, wmean, wdat, na.rm = TRUE))
   # missing weights
   expect_equal(fmean(NA, w = NA), wmean(NA, NA))
   expect_equal(fmean(NA, w = NA, na.rm = FALSE), wmean(NA, NA))
@@ -212,18 +206,18 @@ test_that("fmean with weights performs like wmean (defined above)", {
   expect_equal(fmean(mtcars, w = wdatNA, na.rm = FALSE), dapply(mtcars, wmean, wdatNA))
   expect_equal(fmean(mtcNA, w = wdatNA, na.rm = FALSE), dapply(mtcNA, wmean, wdatNA))
   expect_equal(fmean(mtcNA, w = wdatNA), dapply(mtcNA, wmean, wdatNA, na.rm = TRUE))
-  expect_equal(fmean(x, f, wNA), wBY(x, f, wmean, wNA, na.rm = TRUE))
-  expect_equal(fmean(x, f, wNA, na.rm = FALSE), wBY(x, f, wmean, wNA))
-  expect_equal(fmean(xNA, f, wNA, na.rm = FALSE), wBY(xNA, f, wmean, wNA))
-  expect_equal(fmean(xNA, f, wNA), wBY(xNA, f, wmean, wNA, na.rm = TRUE))
-  expect_equal(fmean(m, g, wdatNA), wBY(m, gf, wmean, wdatNA, na.rm = TRUE))
-  expect_equal(fmean(m, g, wdatNA, na.rm = FALSE), wBY(m, gf, wmean, wdatNA))
-  expect_equal(fmean(mNA, g, wdatNA, na.rm = FALSE),  wBY(mNA, gf, wmean, wdatNA))
-  expect_equal(fmean(mNA, g, wdatNA), wBY(mNA, gf, wmean, wdatNA, na.rm = TRUE))
-  expect_equal(fmean(mtcars, g, wdatNA), wBY(mtcars, gf, wmean, wdatNA, na.rm = TRUE))
-  expect_equal(fmean(mtcars, g, wdatNA, na.rm = FALSE), wBY(mtcars, gf, wmean, wdatNA))
-  expect_equal(fmean(mtcNA, g, wdatNA, na.rm = FALSE), wBY(mtcNA, gf, wmean, wdatNA))
-  expect_equal(fmean(mtcNA, g, wdatNA), wBY(mtcNA, gf, wmean, wdatNA, na.rm = TRUE))
+  expect_equal(fmean(x, f, wNA), BY(x, f, wmean, wNA, na.rm = TRUE))
+  expect_equal(fmean(x, f, wNA, na.rm = FALSE), BY(x, f, wmean, wNA))
+  expect_equal(fmean(xNA, f, wNA, na.rm = FALSE), BY(xNA, f, wmean, wNA))
+  expect_equal(fmean(xNA, f, wNA), BY(xNA, f, wmean, wNA, na.rm = TRUE))
+  expect_equal(fmean(m, g, wdatNA), BY(m, gf, wmean, wdatNA, na.rm = TRUE))
+  expect_equal(fmean(m, g, wdatNA, na.rm = FALSE), BY(m, gf, wmean, wdatNA))
+  expect_equal(fmean(mNA, g, wdatNA, na.rm = FALSE),  BY(mNA, gf, wmean, wdatNA))
+  expect_equal(fmean(mNA, g, wdatNA), BY(mNA, gf, wmean, wdatNA, na.rm = TRUE))
+  expect_equal(fmean(mtcars, g, wdatNA), BY(mtcars, gf, wmean, wdatNA, na.rm = TRUE))
+  expect_equal(fmean(mtcars, g, wdatNA, na.rm = FALSE), BY(mtcars, gf, wmean, wdatNA))
+  expect_equal(fmean(mtcNA, g, wdatNA, na.rm = FALSE), BY(mtcNA, gf, wmean, wdatNA))
+  expect_equal(fmean(mtcNA, g, wdatNA), BY(mtcNA, gf, wmean, wdatNA, na.rm = TRUE))
 })
 
 test_that("fmean performs numerically stable", {
